datastructuretools.TypedFrozenset
=================================

.. abjad-lineage:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset

.. autoclass:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.copy
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.difference
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.intersection
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.isdisjoint
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.issubset
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.issuperset
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.item_class
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.items
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.symmetric_difference
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.union
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__and__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__contains__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__eq__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__format__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__ge__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__gt__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__hash__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__iter__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__le__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__len__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__lt__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__ne__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__or__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__repr__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__sub__
      ~abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__xor__

Bases
-----

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.item_class
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.items
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.copy
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.difference
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.intersection
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.isdisjoint
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.issubset
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.issuperset
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.union
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__and__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__contains__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__format__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__hash__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__iter__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__len__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__or__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__repr__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__sub__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.__xor__
   :noindex:
